@@ -21,7 +21,7 @@ compensates for some of the idiosyncrasies of ODBC.
 
 =cut
 
-=head2 CaseSensitive
+=head2 case_sensitive
 
 Returns a false value.
 
@@ -32,30 +32,30 @@ sub case_sensitive {
     return (undef);
 }
 
-=head2 BuildDSN
+=head2 build_dsn
 
 =cut
 
 sub build_dsn {
     my $self = shift;
     my %args = (
-        Driver   => undef,
-        Database => undef,
-        Host     => undef,
-        Port     => undef,
+        driver     => undef,
+        database   => undef,
+        host       => undef,
+        port       => undef,
         @_
     );
 
-    my $dsn = "dbi:$args{'Driver'}:$args{'Database'}";
-    $dsn .= ";host=$args{'Host'}"
-        if ( defined $args{'Host'} && $args{'Host'} );
-    $dsn .= ";port=$args{'Port'}"
-        if ( defined $args{'Port'} && $args{'Port'} );
+    $args{dbname} ||= delete $args{database};
+
+    my $dsn = "dbi:$args{driver}:$args{dbname}";
+    $dsn .= ";host=$args{'host'}" if $args{'host'};
+    $dsn .= ";port=$args{'port'}" if $args{'port'};
 
     $self->{'dsn'} = $dsn;
 }
 
-=head2 ApplyLimits
+=head2 apply_limits
 
 =cut
 
@@ -70,7 +70,7 @@ sub apply_limits {
     $$statementref =~ s/SELECT\b/SELECT $limit_clause/;
 }
 
-=head2 DistinctQuery
+=head2 distinct_query
 
 =cut
 
@@ -78,9 +78,17 @@ sub distinct_query {
     my $self         = shift;
     my $statementref = shift;
 
+    my $sb = shift;
+
     $$statementref = "SELECT main.* FROM $$statementref";
+    $$statementref .= $sb->_group_clause;
+    $$statementref .= $sb->_order_clause;
 }
 
+=head2 encoding
+
+=cut
+
 sub encoding {
 }
 
@@ -90,7 +98,7 @@ __END__
 
 =head1 AUTHOR
 
-Autrijus Tang
+Audrey Tang C<cpan@audreyt.org>
 
 =head1 SEE ALSO
 
